<?php
/**
 * @package    com_responsibilities
 * @subpackage helpers
 * @author     Alexander Grözinger {@link http://www.agmedia.de}
 * @author     Created on Mar-2018
 * @license    GNU/GPL
 * @copyright  AGMedia.de
 */
/*
   _   ___ __  __        _ _           _
  /_\ / __|  \/  |___ __| (_)__ _   __| |___
 / _ \ (_ | |\/| / -_) _` | / _` |_/ _` / -_)
/_/ \_\___|_|  |_\___\__,_|_\__,_(_)__,_\___|
*/

// No direct access to this file
defined('_JEXEC') or die(';-)');

/**
 * ThirdParty Component Category Tree
 * @since 1.0.0
 */
class ResponsibilitiesCategories extends JCategories
{
    /**
     * Constructor
     *
     * @param   array  $options  Array of options
     * @since   1.0.0
     */
    public function __construct($options = array())
    {
		$options['table'] = '#__responsibilities';
		$options['extension'] = 'com_responsibilities';

		parent::__construct($options);
    }

    public function getCategoriesTree($max_level = 0) {
        $db = JFactory::getDbo();

        $query  = $db->getQuery(true);
        $query  ->select('n.title, COUNT(*)-1 AS level, n.id as id')
            ->from('#__categories AS n, #__categories AS p')
            ->where('n.lft BETWEEN p.lft AND p.rgt')
            ->where($db->quoteName('n.extension') 	.' = '. $db->quote('com_responsibilities'));

        //If $max_level is set
        if($max_level > 0) {
            $query->where($db->quoteName('n.level') 	.' <= '. $db->quote($max_level));
        }

        $query->group('n.lft');
        $query->order('n.lft');

        $db->setQuery($query);
        $db->execute();
        $count = $db->getNumRows();
        $result = $db->loadAssocList();

        if($count < 1) return array();
        return $result;
    }

    public function getCategoryTree($cat_id) {
    	$categories = new ResponsibilitiesCategories;
		$category_tree = array();

		if($cat_id > 0) {
			$category = $categories->get($cat_id);

			while($category->level > 0) {
				
				$tmp_array = array();
				$tmp_array['level'] = $category->level;
				$tmp_array['title'] = $category->title;
				$category_tree[] = $tmp_array;
				
				if($category->parent_id > 0) {
					$category = $categories->get($category->parent_id);
				} else {
					break;
				}
			}
		}
		
		//Array sortieren
		usort($category_tree, function ($a, $b){
			if($a["level"] == $b["level"]) {
				return strcmp($a["level"], $b["level"]);
			}
			
			return strcmp($a["level"], $b["level"]);
		});  
	
		
		return $category_tree;	
		// echo "<pre>"; print_r($category_tree); exit;
    }
    
    public function getCategoryTreeText($cat_id) {
    	$category_tree = $this->getCategoryTree($cat_id);
    	$string = '';
    	$spacer = '|--';

    	if(!empty($category_tree)) {
			foreach($category_tree as $node) {
				if($node['level'] > 0) {
					
					for($i=1;$i<$node['level'];$i++) $string .= $spacer;
					$string .= ' ';
				}
				
				$string .= $node['title'] . '<br>';
			}    		
    	}

    	return $string;
    }
}