<?php
/**
 * @package    com_responsibilities
 * @subpackage views
 * @author     Alexander Grözinger {@link http://www.agmedia.de}
 * @author     Created on Mar-2018
 * @license    GNU/GPL
 * @copyright  AGMedia.de
 */
/*
   _   ___ __  __        _ _           _
  /_\ / __|  \/  |___ __| (_)__ _   __| |___
 / _ \ (_ | |\/| / -_) _` | / _` |_/ _` / -_)
/_/ \_\___|_|  |_\___\__,_|_\__,_(_)__,_\___|
*/

// No direct access to this file
defined('_JEXEC') or die(';-)');

/**
 * HTML View class for the com_responsibilities Component.
 *
 * @package    Assignments
 * @subpackage Views
 * @since 1.0.0
 */
class ResponsibilitiesViewAssignments extends JViewLegacy
{
    public $sidebar;
    public $categories;
    public $items;
    public $state;
    public $pagination;
    public $filterForm;
    public $activeFilters;

    protected $canDo;

    public function display($tpl = null)
    {
      //$this->item = $this->get('Items');

		//+++++++++++++++++++++++++++++++++++
    	//+ ACCESS CHECK
    	//+++++++++++++++++++++++++++++++++++
		$this->canDo = JHelperContent::getActions('com_responsibilities');

		if  (		!$this->canDo->get('core.create') 
				&&	!$this->canDo->get('core.edit') 
				&&	!$this->canDo->get('core.delete')  
				&&	!$this->canDo->get('core.edit.own')
			)
		{
			JToolBarHelper::title(JText::_('COM_RESPONSIBILITIES_ACCESS_DENIED'));
			// Add Back button
			$button = '<div class="btn-group">
			          <button type="button" class="btn btn-default" aria-haspopup="true" aria-expanded="false" onclick="location.href=\''.JRoute::_('index.php?option=com_responsibilities').'\'">
			            <span class="icon-arrow-left-4"></span> ' . JText::_('COM_RESPONSIBILITIES_SIDEBAR_BACK') . '
			          </button>';
			$toolbar = JToolbar::getInstance();
			$toolbar->appendButton('Custom', $button);

			JError::raiseError(403, 'Du hast nicht die erfordeliche Berechtigung. Kontaktiere bitte einen Administrator.');		
			return false;
			//throw new JAccessExceptionNotallowed(JText::_('JERROR_ALERTNOAUTHOR'), 403);
		}    
		
		//+++++++++++++++++++++++++++++++++++
    	//+ ACCESS GRANTED
    	//+++++++++++++++++++++++++++++++++++        	
		$this->categories    = $this->get('CategoryOrders');
		$this->items         = $this->get('Items');
		$this->pagination    = $this->get('Pagination');
		$this->state         = $this->get('State');
		$this->filterForm    = $this->get('FilterForm');
		$this->activeFilters = $this->get('ActiveFilters');

        //Sidebar
        ResponsibilitiesHelper::addSubmenu('Assignments');
        $this->sidebar = AgmLibAdminSidebar::render('com_responsibilities');

        $this->addToolbar();

        // Auf Fehler prüfen
        $errors = $this->get('Errors');

        if (count($errors))
        {
            JError::raiseError(500, implode('<br />', $errors));

            return false;
        }

        parent::display($tpl);		
   }

    protected function addToolbar()
    {
        JToolBarHelper::title(JText::_('COM_RESPONSIBILITIES_ADMIN'));

        $user = JFactory::getUser();
        if ($this->canDo->get('core.create'))
        {
		    JToolBarHelper::addNew(	'assignment.add', 'JTOOLBAR_NEW');
        }

        if ($this->canDo->get('core.edit'))
        {
		    JToolBarHelper::editList('assignment.edit', 'JTOOLBAR_EDIT');
        }

        if ($this->canDo->get('core.edit.state'))
        {
            if ($this->state->get('filter.published') != 2)
            {
                JToolbarHelper::publish(	'assignments.publish', 'JTOOLBAR_PUBLISH', true);
                JToolbarHelper::unpublish(	'assignments.unpublish', 'JTOOLBAR_UNPUBLISH', true);
            }

        }

        if ($this->canDo->get('core.edit.state'))
        {
            JToolbarHelper::checkin(	'assignments.checkin');
        }

        if ($this->state->get('filter.published') == -2 && $this->canDo->get('core.delete'))
        {
            JToolBarHelper::deleteList(	'JGLOBAL_CONFIRM_DELETE', 'Assignments.delete', 'JTOOLBAR_EMPTY_TRASH');
        }
        elseif ($this->canDo->get('core.edit.state'))
        {
            JToolbarHelper::trash('assignments.trash');
        }

        if ($user->authorise('core.admin', 'com_responsibilities') || $user->authorise('core.options', 'com_responsibilities'))
        {
            //JToolBarHelper::divider();
            JToolbarHelper::preferences('com_responsibilities');
        }

    }
    
    protected function getSortFields()
	{
		return array(
		'a.ordering' => JText::_('JGRID_HEADING_ORDERING'),
		'a.state' => JText::_('JSTATUS'),
		'a.title' => JText::_('JGLOBAL_TITLE'),
		'a.id' => JText::_('JGRID_HEADING_ID')
		);
	}
}
